const {WakaTime} = require('wakatime');
const format = require('date-fns/format');

const wakaTimeInstance = new WakaTime(process.env.WAKATIME_TOKEN);

const formatTime = time => {
  return format(time, 'YYYY-MM-DD HH:mm')
}

const wakatimeHandler = async (context, next) => {
  if (context.event.isMessage && context.event.message.text === 'wakatime') {
    await context.sendMessage('select range', {
      reply_markup: {
        "inline_keyboard": [
          [{
            text: 'Today',
            callback_data: 'wakatime-today'
          }],
          [{
            text: 'This week',
            callback_data: 'wakatime-week'            
          }]
        ]
      }
    })
  } else if (context.event.isCallbackQuery) {
    if (context.event.rawEvent.callback_query.data === 'wakatime-today') {
      await wakaTimeInstance.summaries(new Date()).then(re => {
        const data = re.data[0];
        const text =
`
----------------------------------------------------------------------
Wakatime report from ${formatTime(re.start)} to ${formatTime(re.end)}:

*Total Time: ${data.grand_total.text}*

*Project Time*:
${data.projects.map(project => `．${project.name}: ${project.text}`).join('\n')}
----------------------------------------------------------------------

`
        return context.sendMessage(text, {parse_mode: 'Markdown'});
      })
    }
  }
}

module.exports = wakatimeHandler;